==> jc-1.4.0.tar.gz: gnu/java/net/protocol/jar/Handler.h <==
// public class gnu.java.net.protocol.jar.Handler

// class file dependencies
// @dep_class d21e7b12ca58721c gnu_java_net_protocol_jar_Handler
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d7e769aebe17520e java_net_URLStreamHandler

// header file dependencies
// @dep_header java_net_URLStreamHandler

#include "java/net/URLStreamHandler.h"

#ifndef _JC_gnu_java_net_protocol_jar_Handler_H_
#define _JC_gnu_java_net_protocol_jar_Handler_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_net_URL$object;
struct _jc_java_net_URLConnection$object;

// Typedefs
typedef struct _jc_gnu_java_net_protocol_jar_Handler$sub_refs	_jc_gnu_java_net_protocol_jar_Handler$sub_refs;
typedef struct _jc_gnu_java_net_protocol_jar_Handler$sub_nonrefs	_jc_gnu_java_net_protocol_jar_Handler$sub_nonrefs;
typedef struct _jc_gnu_java_net_protocol_jar_Handler$refs	_jc_gnu_java_net_protocol_jar_Handler$refs;
typedef struct _jc_gnu_java_net_protocol_jar_Handler$nonrefs	_jc_gnu_java_net_protocol_jar_Handler$nonrefs;
typedef struct _jc_gnu_java_net_protocol_jar_Handler$object	_jc_gnu_java_net_protocol_jar_Handler$object;

typedef const struct _jc_gnu_java_net_protocol_jar_Handler$vmethods	_jc_gnu_java_net_protocol_jar_Handler$vmethods;
typedef const struct _jc_gnu_java_net_protocol_jar_Handler$vtable	_jc_gnu_java_net_protocol_jar_Handler$vtable;
typedef const struct _jc_gnu_java_net_protocol_jar_Handler$vtype	_jc_gnu_java_net_protocol_jar_Handler$vtype;

// Constructors
extern void _jc_gnu_java_net_protocol_jar_Handler$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_net_protocol_jar_Handler$object *);

// Virtual methods
extern struct _jc_java_net_URLConnection$object *_jc_gnu_java_net_protocol_jar_Handler$method$openConnection$7768e1cfcb90de35(_jc_env *, struct _jc_gnu_java_net_protocol_jar_Handler$object *, struct _jc_java_net_URL$object *);
extern void _jc_gnu_java_net_protocol_jar_Handler$method$parseURL$29050b0475d6d060(_jc_env *, struct _jc_gnu_java_net_protocol_jar_Handler$object *, struct _jc_java_net_URL$object *, struct _jc_java_lang_String$object *, jint, jint);
extern struct _jc_java_lang_String$object *_jc_gnu_java_net_protocol_jar_Handler$method$toExternalForm$330af71074ca3ddf(_jc_env *, struct _jc_gnu_java_net_protocol_jar_Handler$object *, struct _jc_java_net_URL$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_net_protocol_jar_Handler$method_info$openConnection$7768e1cfcb90de35;
extern _jc_method _jc_gnu_java_net_protocol_jar_Handler$method_info$parseURL$29050b0475d6d060;
extern _jc_method _jc_gnu_java_net_protocol_jar_Handler$method_info$toExternalForm$330af71074ca3ddf;

// Virtual methods structure
struct _jc_gnu_java_net_protocol_jar_Handler$vmethods {
	struct _jc_java_net_URLConnection$object	*(*openConnection$7768e1cfcb90de35)(_jc_env *, struct _jc_gnu_java_net_protocol_jar_Handler$object *, struct _jc_java_net_URL$object *);
	void	(*parseURL$29050b0475d6d060)(_jc_env *, struct _jc_gnu_java_net_protocol_jar_Handler$object *, struct _jc_java_net_URL$object *, struct _jc_java_lang_String$object *, jint, jint);
	struct _jc_java_lang_String$object	*(*toExternalForm$330af71074ca3ddf)(_jc_env *, struct _jc_gnu_java_net_protocol_jar_Handler$object *, struct _jc_java_net_URL$object *);
};

// Vtable
struct _jc_gnu_java_net_protocol_jar_Handler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_net_URLStreamHandler$vmethods	java_net_URLStreamHandler;
	_jc_gnu_java_net_protocol_jar_Handler$vmethods	gnu_java_net_protocol_jar_Handler;
};

// Vtype
struct _jc_gnu_java_net_protocol_jar_Handler$vtype {
	_jc_type			type;
	_jc_gnu_java_net_protocol_jar_Handler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_jar_Handler$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_net_protocol_jar_Handler$refs {
    _jc_gnu_java_net_protocol_jar_Handler$sub_refs	gnu_java_net_protocol_jar_Handler;
    _jc_java_net_URLStreamHandler$sub_refs	java_net_URLStreamHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_jar_Handler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_protocol_jar_Handler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_net_URLStreamHandler$sub_nonrefs	java_net_URLStreamHandler;
    _jc_gnu_java_net_protocol_jar_Handler$sub_nonrefs	gnu_java_net_protocol_jar_Handler;
};

// Object instance structure
struct _jc_gnu_java_net_protocol_jar_Handler$object {
	_jc_gnu_java_net_protocol_jar_Handler$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_protocol_jar_Handler$vtype	*vtype;
	_jc_gnu_java_net_protocol_jar_Handler$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_protocol_jar_Handler$vtype _jc_gnu_java_net_protocol_jar_Handler$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_protocol_jar_Handler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_protocol_jar_Handler$class_object;

#endif	/* _JC_gnu_java_net_protocol_jar_Handler_H_ */

==> jc-1.4.5.tar.gz: gnu/java/net/protocol/jar/Handler.h <==
// public class gnu.java.net.protocol.jar.Handler

// class file dependencies
// @dep_class f8e538006919b037 gnu_java_net_protocol_jar_Handler
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d7e769aebe17520e java_net_URLStreamHandler

// header file dependencies
// @dep_header java_net_URLStreamHandler

#include "java/net/URLStreamHandler.h"

#ifndef _JC_gnu_java_net_protocol_jar_Handler_H_
#define _JC_gnu_java_net_protocol_jar_Handler_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_net_URL$object;
struct _jc_java_net_URLConnection$object;

// Typedefs
typedef struct _jc_gnu_java_net_protocol_jar_Handler$sub_refs	_jc_gnu_java_net_protocol_jar_Handler$sub_refs;
typedef struct _jc_gnu_java_net_protocol_jar_Handler$sub_nonrefs	_jc_gnu_java_net_protocol_jar_Handler$sub_nonrefs;
typedef struct _jc_gnu_java_net_protocol_jar_Handler$refs	_jc_gnu_java_net_protocol_jar_Handler$refs;
typedef struct _jc_gnu_java_net_protocol_jar_Handler$nonrefs	_jc_gnu_java_net_protocol_jar_Handler$nonrefs;
typedef struct _jc_gnu_java_net_protocol_jar_Handler$object	_jc_gnu_java_net_protocol_jar_Handler$object;

typedef const struct _jc_gnu_java_net_protocol_jar_Handler$vmethods	_jc_gnu_java_net_protocol_jar_Handler$vmethods;
typedef const struct _jc_gnu_java_net_protocol_jar_Handler$vtable	_jc_gnu_java_net_protocol_jar_Handler$vtable;
typedef const struct _jc_gnu_java_net_protocol_jar_Handler$vtype	_jc_gnu_java_net_protocol_jar_Handler$vtype;

// Constructors
extern void _jc_gnu_java_net_protocol_jar_Handler$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_net_protocol_jar_Handler$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_net_URLConnection$object *_jc_gnu_java_net_protocol_jar_Handler$method$openConnection$7768e1cfcb90de35(_jc_env *, struct _jc_gnu_java_net_protocol_jar_Handler$object *, struct _jc_java_net_URL$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_net_protocol_jar_Handler$method$parseURL$29050b0475d6d060(_jc_env *, struct _jc_gnu_java_net_protocol_jar_Handler$object *, struct _jc_java_net_URL$object *, struct _jc_java_lang_String$object *, jint, jint) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_java_net_protocol_jar_Handler$method$toExternalForm$330af71074ca3ddf(_jc_env *, struct _jc_gnu_java_net_protocol_jar_Handler$object *, struct _jc_java_net_URL$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_net_protocol_jar_Handler$method_info$openConnection$7768e1cfcb90de35;
extern _jc_method _jc_gnu_java_net_protocol_jar_Handler$method_info$parseURL$29050b0475d6d060;
extern _jc_method _jc_gnu_java_net_protocol_jar_Handler$method_info$toExternalForm$330af71074ca3ddf;

// Virtual methods structure
struct _jc_gnu_java_net_protocol_jar_Handler$vmethods {
	struct _jc_java_net_URLConnection$object	*(*openConnection$7768e1cfcb90de35)(_jc_env *, struct _jc_gnu_java_net_protocol_jar_Handler$object *, struct _jc_java_net_URL$object *) _JC_JCNI_ATTR;
	void	(*parseURL$29050b0475d6d060)(_jc_env *, struct _jc_gnu_java_net_protocol_jar_Handler$object *, struct _jc_java_net_URL$object *, struct _jc_java_lang_String$object *, jint, jint) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toExternalForm$330af71074ca3ddf)(_jc_env *, struct _jc_gnu_java_net_protocol_jar_Handler$object *, struct _jc_java_net_URL$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_net_protocol_jar_Handler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_net_URLStreamHandler$vmethods	java_net_URLStreamHandler;
	_jc_gnu_java_net_protocol_jar_Handler$vmethods	gnu_java_net_protocol_jar_Handler;
};

// Vtype
struct _jc_gnu_java_net_protocol_jar_Handler$vtype {
	_jc_type			type;
	_jc_gnu_java_net_protocol_jar_Handler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_jar_Handler$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_net_protocol_jar_Handler$refs {
    _jc_gnu_java_net_protocol_jar_Handler$sub_refs	gnu_java_net_protocol_jar_Handler;
    _jc_java_net_URLStreamHandler$sub_refs	java_net_URLStreamHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_jar_Handler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_protocol_jar_Handler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_net_URLStreamHandler$sub_nonrefs	java_net_URLStreamHandler;
    _jc_gnu_java_net_protocol_jar_Handler$sub_nonrefs	gnu_java_net_protocol_jar_Handler;
};

// Object instance structure
struct _jc_gnu_java_net_protocol_jar_Handler$object {
	_jc_gnu_java_net_protocol_jar_Handler$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_protocol_jar_Handler$vtype	*vtype;
	_jc_gnu_java_net_protocol_jar_Handler$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_protocol_jar_Handler$vtype _jc_gnu_java_net_protocol_jar_Handler$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_protocol_jar_Handler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_protocol_jar_Handler$class_object;

#endif	/* _JC_gnu_java_net_protocol_jar_Handler_H_ */
